%
%                            COADS CLIMATOLOGIES

% FUNCTIONS -- REQUIRED
GetFunctionName = 'getrectg';

% FUNCTIONS -- OPTIONAL
URL_m_File = 'pmelurl';
CatalogServer = 'monthly';

% VARIABLES -- OPTIONAL
Server = 'http://ferret.wrc.noaa.gov/cgi-bin/nph-nc/data/COADS_climatology.nc';
Nlon = 180;
Nlat = 90;

% VARIABLES -- REQUIRED
LonRange = [20.000 380.000];
LatRange = [-90.000 90.000];
TimeRange = [1800 2000];
DepthRange = [0.0 0.0];
DepthUnits = '';
Resolution = 219.5;

%DataName = 'COADS Climatologies';
                                          % PCC Changed 12/13/98 to regularize names.
DataName = 'Surface - COADS Monthly Climatologies - PMEL';
TimeName = 'TIME';
LongitudeName = 'COADSX';
LatitudeName = 'COADSY';
DepthName = '';

% these names tie in to the browser as recognized common strings
% linking different datasets
SelectableVariables = str2mat('Pressure','Air_Temp', ...
    'Spec_Humidity', 'Sea_Temp', 'U_Wind','V_Wind');
% there must be one DODSNAME for each selectable variable
DodsName = str2mat('SLP','AIRT','SPEH', 'SST', 'UWND','VWND');

% note: DataNull is applied *before* scaling
DataNull = [NaN NaN NaN NaN ...
      -9999999790214767953607394487959552.0 ...
      -9999999790214767953607394487959552.0 ...
      -9999999790214767953607394487959552.0 ...
      -9999999790214767953607394487959552.0 ...
      -9999999790214767953607394487959552.0 ...
      -9999999790214767953607394487959552.0];
DataScale = [NaN NaN; NaN NaN; NaN NaN; NaN NaN; 0 1; 0 1; 0 1; ...
  0 1; 0 1; 0 1];
DataRange = [NaN NaN; NaN NaN; NaN NaN; NaN NaN; 970.0 1050.0; ...
  -65.0 65.0; 4 25; 0.0 32.0; -25.0 25.0; -25.0 25.0];

Data_Use_Policy = '';

Acknowledge = sprintf('%s\n\n%s\n%s\n%s\n%s\n%s', ...
    [ 'The principal investigators in the production of these data are ',...
      'J.D. Elms, S.D. Woodruff, and S. Worley ',...
      '(http://www.cdc.noaa.gov/coads/participants.html).', ...
      'These data were provided by the Ferret development group of', ...
      ' the Thermal Modeling and Analysis Project at NOAA''s Pacific', ...
      ' Marine Environmental Laboratory in Seattle Washington (PMEL:', ...
      ' http://www.pmel.noaa.gov  Ferret: http://ferret.pmel.noa.gov).', ...
      'and accessed via the Distributed Oceanographic Data System ',...
      '(DODS: http://www.unidata.ucar.edu/packages/dods).'], ...
      [ 'Citations: Diaz, H.F., K. Wolter, and S.D. Woodruff (Eds.), '...
      '1992: Proceedings of the International COADS Workshop, '...
      'Boulder, Colorado, 13-15 January 1992. NOAA Environmental ',...
      'Research Laboratories, Climate Research Program, ', ...
      'Boulder, CO, 390 pp.'], ...
    [ 'Elms, J.D., S.D. Woodruff, S.J. Worley, and C. Hanson, 1994: ',...
      'Digitizing Historical Records for the Comprehensive Ocean-Atmosphere ',...
      'Data Set (COADS) Earth System Monitor, 4, No. 2, 4-10.'], ...
    [ 'Slutz, R.J., S.J. Lubker, J.D. Hiscox, S.D. Woodruff, R.L. ', ...
      'Jenne, D.H. Joseph, P.M. Steurer, and J.D. Elms, 1985: ',...
      'Comprehensive Ocean-Atmosphere Data Set; Release 1. NOAA ',...
      'Environmental Research Laboratories, Climate Research Program, ', ...
      'Boulder, CO, 268 pp.'],...
    [ 'Woodruff, S.D., S.J. Lubker, K. Wolter, S.J. Worley, and J.D. ',...
      'Elms, 1993: Comprehensive Ocean-Atmosphere Data Set (COADS) Release ',...
      '1a: 1980-92. Earth System Monitor, 4, No. 1 September 1993, ',...
      '1-8.'], ...
    [ 'Woodruff, S.D., R.J. Slutz, R.L. Jenne, and P.M. Steurer, 1987: ',...
      'A comprehensive ocean-atmosphere data set. Bull. Amer. Meteor. ',...
      'Soc., 68, 1239-1250.']);
  
% COMMENTS
Comments1 = sprintf('%s\n', ...
'         COADS (Comprehensive Ocean-Atmosphere Data Set) Data at PMEL', ...
'            S.L. Pressure, Temperature, and Spec. Hum. Climatologies ', ...
'    ',...
'    COADS is the result of a continuing cooperative project between the ',...
'    National Oceanic and Atmospheric Administration (NOAA) -- ',...
'    specifically its Environmental Research Laboratories (ERL),', ...
'    National Climatic Data Center (NCDC), and Cooperative Institute ',...
'    for Research in Environmental Sciences (CIRES, conducted jointly ',...
'    with the University of Colorado) -- and the National Science ',...
'    Foundation''s National Center for Atmospheric Research (NCAR). ',...
'    The NOAA portion of COADS is currently supported by the NOAA ',...
'     Climate and Global Change (C&GC) Program and the NOAA ',...
'    Environmental Services Data and Information Management (ESDIM) ',...
'    Program. ', ...
'    ', ...
'    These data are monthly averaged ', ...
'    observations based on data available during the time period 1854-1992 for ', ...
'    that month binned on a global 2x2 degree grid (i.e., the dataset contains 12 ', ...
'    grids, one for each month of the year). Data values are given in millibars. ', ...
'    ', ...
'    Note:  The origin of the data grid (indicies (1,1)) has a lat/long value of ', ...
'    (-90,20), and a corresponding terminal point (indices (90,180)) corresponding ', ...
'    to (90,380).  Longitude values span 360 degrees, from 20-380 degrees.', ...
'    ', ...
'                      General Summary of the COADS Data ', ...
'    ', ...
'    The Comprehensive Ocean-Atmosphere Data Set (COADS)* has been created by ', ...
'    combining, editing, and summarizing global in situ marine data from many ', ...
'    different sources.  Merchant ship observations back to 1854 have been ', ...
'    supplemented in more recent years by automated measurements, e.g., from ', ...
'    drifting and moored buoys.  COADS currently covers the period 1854-1992.  Two ', ...
'    COADS products are most often requested by users (decadal summaries and other ', ...
'    products are also available): ', ...
'         i) Marine reports: These contain the basic individual observations (e.g., ', ...
'         of air and sea surface temperatures, winds, atmospheric pressure, ', ...
'         cloudiness, and humidity) taken from the ocean-atmosphere boundary layer. ', ...
'    ', ...
'         ii) Global monthly summaries for 2-degree latitude x 2-degree longitude ', ...
'         boxes.  Fourteen statistics, such as the median and mean, were calculated ', ...
'         for each of 19 observed and derived variables.  The statistics are global ', ...
'         only to the extent that observations were actually recorded at a given ', ...
'         time and place (i.e., statistics were calculated for each year, month, and ', ...
'         2-degree box containing "acceptable" data).  Due to data volume, ', ...
'         statistics are often requested in the form of group files, each group ', ...
'         containing eight selected statistics for four variables. ', ...
'    ', ...
'    The various COADS datasets available from the NOAA/PMEL Archive reference the ', ...
'    following parameters:');

Comments2 = sprintf('%s\n', ...
'    ', ...
'    "Observed" variables             Name     Units           Precision ', ...
'      Air temperature                      air        deg C           0.01 ', ...  
'      Sea level pressure                 slp        mb                0.01 ', ...
'      Sea surface temperature        sst       deg C           0.01 ', ...
'      u-wind                                   uwnd    m/s               0.01 ', ...
'      v-wind                                   vwnd    m/s               0.01 ', ...
'      Scalar wind                            wspd    m/s               0.01 ', ...
'      Cloudiness                             cldc      okta              0.1 ', ...
'      Specific humidity                    shum    g/kg              0.01 ', ...
'    ', ...
'    Derived variables', ...
'      Relative humidity                    rhum     %                 0.1  ', ...
'      Sensible heat parameter ', ...
'        (sst - air) * wspd                 sflx    degC*m/s        0.1 ', ...
'      Latent heat parameter ((saturation', ...
'        shum at sst) - shum)*wspd   lflx     g/kg               0.01 ', ...
'      u-wind stress (wspd * uwnd)   ustr    m^2/s^2        0.1 ', ...
'      v-wind stress (wspd * vwnd)   vstr    m^2/s^2        0.1 ', ... 
'    ');

Comments3 = sprintf('%s\n', ...
'    Statistic                               Abbreviation', ...
'    ', ...
'      Mean                                       mean', ...
'      Number of Observations           nobs', ...
'      Long Term Mean                      ltm', ...
'    ', ...
'    Spatial coverage: ', ...
'    ', ...
'         90N-90S (by 2.0), 1-359E (by 2.0) ', ...
'         (specified coordinates refer to center of 2-degree boxes) ', ...
'    ', ...
'    Temporal coverage: ', ...
'    ', ...
'         January 1854 through December 1992 ', ...
'         monthly means and monthly numbers of observations ', ...
'    ', ...
'    Levels: ', ...
'    ', ...
'         Surface data.  ', ...         
'    ', ...
'    References: ', ...
'     ', ...
'      Homepage for COADS: ', ...
'      http://www.cdc.noaa.gov/coads/', ...
'    ', ...
'      Publications and on-line documentation for COADS: ', ...
'      http://www.cdc.noaa.gov/coads/publications.html', ...
'    ', ...
'       Diaz, H.F., K. Wolter, and S.D. Woodruff (Eds.), 1992: Proceedings of the ', ...
'          International COADS Workshop, Boulder, Colorado, 13-15 January 1992. ', ...
'          NOAA Environmental Research Laboratories, Climate Research Program, ', ...
'          Boulder, CO, 390 pp.', ...
'    ', ...
'       Elms, J.D., S.D. Woodruff, S.J. Worley, and C. Hanson, 1994: Digitizing ', ...
'          Historical Records for the Comprehensive Ocean-Atmosphere Data Set ', ...
'          (COADS) Earth System Monitor, 4, No. 2, 4-10.', ...
'    ', ...
'       Slutz, R.J., S.J. Lubker, J.D. Hiscox, S.D. Woodruff, R.L. Jenne, D.H. ', ...
'          Joseph, P.M. Steurer, and J.D. Elms, 1985: Comprehensive Ocean-Atmosphere ', ...
'          Data Set; Release 1. NOAA EnvironmentalResearch Laboratories, Climate ', ...
'          Research Program, Boulder, CO, 268 pp.', ...
'    ', ...
'       Woodruff, S.D., S.J. Lubker, K. Wolter, S.J. Worley, and J.D. Elms, 1993: ', ...
'          Comprehensive Ocean-Atmosphere Data Set (COADS) Release 1a: 1980-92. ', ...
'          Earth System Monitor, 4, No. 1 September 1993, 1-8.', ...
'    ', ...
'       Woodruff, S.D., R.J. Slutz, R.L. Jenne, and P.M. Steurer, 1987: A ', ...
'          comprehensive ocean-atmosphere data set. Bull. Amer. Meteor. Soc., 68, ', ...
'          1239-1250.');
Comments4 = sprintf('%s\n', ...
'   ', ...
'    Time_Period_of_Content = ', ...
'         Beginning_Date:1946 ', ...
'         Ending_Date:1992 ', ...
'    Spatial_Domain = ', ...
'         Bounding Coordinates: ', ...
'              West Bounding Coordinate:0.0 ', ...
'              East Bounding Coordinate:360.0 ', ...
'              South Bounding Coordinate:-90.00 ', ...
'              North Bounding Coordinate:+90.00 ', ...
'   ', ...
'    Point_of_Contact (Science) = ', ...
'         Address: ', ...
'               Scott Woodruff ', ...
'               Climate Diagnostics Center ', ...
'               NOAA/ERL/R/E/CD ', ...
'               325 Broadway ', ...
'               Boulder, Colorado 80303 ', ...
'               USA ', ...
'               Phone: (303) 497-6747', ...
'         Electronic Mail Address:INTERNET > sdw@cdc.noaa.gov ', ...
'    Point_of_Contact (Data Provision) = ', ...
'         Address: ', ...
'               Kevin O''Brien ', ...
'               NOAA/PMEL', ...
'               7600 Sand Point Way NE', ...
'               Seattle, Washington 98115-0070', ...
'               USA ', ...
'               Telephone: (206) 526-6751', ...
'         Electronic Mail Address:INTERNET > ferret@pmel.noaa.gov');

Comments = [Comments1 Comments2 Comments3 Comments4];

