%
%  GLOBEC CTD Data from R. Limeburner

% 
% $Log: gbrlctd.m,v $
% Revision 1.5  2000/05/15 18:34:34  kwoklin
% Pointing server to dods.    klee
%
% Revision 1.4  2000/04/11 18:37:02  kwoklin
% Elimilate warning msg.  Add to handle full size constraint request.  klee
%
% Revision 1.3  1999/07/15 20:10:20  kwoklin
% Change Oxygen to Dissolved_Oxygen.   klee
%
% Revision 1.1  1999/06/01 07:10:33  dbyrne
%
%
% Moved up from kleedata/
%
% Revision 1.3  1999/05/28 22:53:05  kwoklin
% Point to new server for all jgofs datasets. Update getjgsta on loaddods.
% Fix infotext for all gb geturl files. Fix transmissivity for some gb
% files. Modify some variable names on gb files.       klee
%

% $Id: gbrlctd.m,v 1.5 2000/05/15 18:34:34 kwoklin Exp $
%  klee 04/99

GetFunctionName = 'getjgsta';

Server = 'http://dods.gso.uri.edu/cgi-bin/nph-jg/rlctd'; 
CatalogServer = nan;
Cat_m_File = 'gbrlctdc';
URL_m_File = 'gbrlctdu';

LonRange = [-69 -65.5]; 
LatRange = [40.0 42.5];   
TimeRange = [1994.39452055 1995.52602741];
DepthRange = [1.0 2128.0];  
Resolution = nan;

DodsName1 = str2mat('year_s','month_s','day_s','time_s');
DodsName = str2mat('temp','sal','o2','flvolt','station');
DataName = 'Water Column - CTD from Some Endeavor Cruises (R. Limeburner) - WHOI/GLOBEC ';    
LongitudeName = str2mat('lon_s');
LatitudeName = str2mat('lat_s');
TimeName = str2mat('year_s','month_s','day_s','time_s','time_e');         
DepthName = 'pres';
DepthUnits = 'dbars';
SelectableVariables = str2mat('Sea_Temp','Salinity','Dissolved_Oxygen','Fluorescence');
%TextField = str2mat('CI9407','EN259','EN260','EN262','EN264','EN266','EN267I','EN267II','EN269');
OptionalVariables = str2mat('depth_w');
SelectableOptional = str2mat('Depth_Water');

Acknowledge = [];
Data_Use_Policy = sprintf('%s' ,...
      'Any person making substantial use of a data set must communicate with the investigators who acquired the data prior to publication and anticipate that the data collectors will be co-authors of published results. This extends to model results and to data organized for retrospective studies. (Please refer to U.S. GLOBEC''s data policy Report #10 (http://cbl.umces.edu/fogarty/usglobec/reports/datapol/ datapol.contents.html).) The data available here are intended for scholarly use by the academic and scientific community, with the express understanding that any such use will properly acknowledge the originating investigator. Use or reproduction of any material herein for any commercial purpose is prohibited without prior written permission from the U.S. GLOBEC Georges Bank Data Management Office. (http://globec.whoi.edu/globec-dir/contact_dmo.html)');


%COMMENTS
Comments1 = sprintf('%s\n', ...
'                             CTD Data from R. Limebruner       ',...
'   ',...
'                   Parameter         Description                               Units',...
'                 --------------------------------------------------------------------',...
'   ',...
'                   cruiseid          cruise identification',...
'                   year              Starting year                             UTC',...
'                   station           pre-assigned station number               n/a ',...
'                   year_s            Starting year (duplicates year fiels      UTC',...
'                   month_s           starting month                            UTC (1 - 12)',...
'                   day_s             starting day                              UTC',...
'                   time_s            starting time for the station             UTC ',...
'                   time_e            ending time for the station               UTC ',...
'                   lat_s             starting latitude                         decimal degrees',...
'                   lon_s             starting longitude                        decimal degrees',...
'                   lat_e             ending latitude                           decimal degrees',...
'                   lon_e             ending longitude                          decimal degrees',...
'                   depth_w           water depth                               meters',...
'                   pres_min          minimum pressure                          decibars',...
'                   pres_max          maximum pressure                          decibars',...
'                   temp_min          minimum temperature                       degress centigrade',...
'                   temp_max          maximum tempurature                       degress centigrade',...
'                   sal_min           minimum salinity                          practical salinity units',...
'                   sal_max           maximum salinity                          practical salinity units',...
'                   o2_min            minimum O2                                milliliter per liter',...
'                   o2_max            maximum O2                                milliliter per liter',...
'                   pres              pressure (equates to water depth)         decibars',...
'                   temp              water temperature                         degress centigrade',...
'                   sal               salinity                                  practical salinity units',...
'                   o2                O2                                        milliliter per liter',...
'                   flvolt            fluorometer measurement                   volts',...
'                   light_tran_v      transmission of light                     volts',...
'                   numb_obs          number of observations                    n/a',...
'  ',...
' Note: The data has received little quality checks although there are cruise-specific comments ',...
'       about data quality. Please refer to the following comments for each cruise.');

Comments2 = sprintf('%s\n',...
'  ',...
'       CI9407: Averover = 1DBar; ScanRate = 25.000Hz',...
'       EN259 : 1..CAST SAMPLING INFORMATION WAS EDITED TO BE CONSISTENT WITH THE EVENT LOG.',...
'                  DATES AND TIMES ARE REPORTED AS GMT.  POSITIONS ARE REPORTED AS DEGREES',...
'                  AND MINUTES TO HUNDREDTHS, MINUS VALUES ARE SOUTH AND WEST INDICATORS. ',...
'               2..NO CTD CAST 20.  APPEARS TO BE THE RESULT OF MIS-NUMBERING.',...
'               3..CTD CAST 13 HAS ONLY ONE DATA CYCLE, SURFACE VALUE.  FILE DELETED.',...
'               4..CTD CAST 27.  THE DATA REPORTED FOR CAST 27 IS THE EXACT SAME AS FOR CAST 28. ',...
'                  THE FILE FOR CAST 27 DELETED.',...
'               5..CTD CAST 29.  FLUOROMETER DATA BAD ENTIRE CAST, REPLACED WITH -9.0 BAD/MISSING ',...
'                  DATA INDICATOR.',...
'               6..CTD CAST 30.  TRANSMISSOMETER DATA, DATA SPIKE AT 274 DECIBARS. REPLACED WITH -9.0',...
'               7..OXYGEN DISPLAYS OCCASIONAL DATA SPIKES AND SHIFTS EXTENDING OVER MORE THEN ONE ',...
'                  DECIBAR.  NO ACTION TAKEN ',...
'       EN260 : 1..CAST NUMBERS 26, 27 AND 28 MISSING.',...
'               2..OXYGEN DISPLAYS OCCASIONAL DATA SPIKES EXTENDING OVER MORE THEN ONE DECIBAR',...
'                  (CAST 13 AT 110 DECIBARS, AND CAST 16 AT 41 DECIBARS).  NO ACTION TAKEN.',...
'       EN262 : 1..-9. USED AS A MISSING/BAD DATA INDICATOR.',...
'               2..CAST NUMBERS 20, AND 21.  ALL OXYGEN VALUES BAD.  REPLACED WITH -9',...
'               3..LIGHT TRANSMISSION.  ONE DECIBAR DATA SPIKES REMOVED FROM CAST 2, 5 AND 23,',...
'                  SURFACE VALUES.  A ONE DECIBAR SPIKE REMOVED FROM CAST 21 AT 14 DECIBARS.',...
'               4..FLUORESCENCE.  DATA SPIKE REMOVED FROM CAST 21 AT 14 DECIBARS.',...
'       EN264 : ',...
'       EN266 : 1..-9. USED AS A MISSING/BAD DATA INDICATOR.',...
'               2..DATA FOR CAST NUMBERS 22, AND 23 MISSING.',...
'       EN267I: 1..9. USED AS A MISSING/BAD DATA INDICATOR.',...
'               2..DATA FOR CAST NUMBERS 4, 98, AND 103 MISSING.',...
'               3..CAST 1 AND 81 ALL VALUES REMOVED FROM LAST DATA CYCLE DUE TO DATA SPIKES.',...
'               4..FLUORESCENCE.  DATA OFF SCALE ON THE HIGH SIDE.  SEVERAL CASTS EXCEED THE ',...
'                  MAX. OF VALUE OF 5 VOLTS.  ',...
'       EN267II:1..-9. USED AS A MISSING/BAD DATA INDICATOR.',...
'               2..ONE DECIBAR SALINITY SPIKES REMOVED STATIONS 210 @ 24m, 214 @ 16m and 217 @ 4m.',...
'       EN269 : ',...
'  ',...
'  ');

Comments4 = sprintf('%s\n', ...
'   ', ...
'    Time_Period_of_Content = ', ...
'         Beginning_Date: Jul. 12, 1994 (1994.39472755) ', ...
'         Ending_Date:    Jul. 12, 1995 (1995.53150685)', ...
'    Spatial_Domain = ', ...
'         Bounding Coordinates: ', ...
'              West Bounding Coordinate: 69.2175 W ', ...
'              East Bounding Coordinate: 65.6937 W ', ...
'              South Bounding Coordinate: 40.5158 N ', ...
'              North Bounding Coordinate: 42.3658 N ', ...
'   ', ...
'    Point_of_Contact = ', ...
'         Address - si: ', ...
'               Richard Limeburner', ...
'               Clark 343A, MS #21 ',...
'               Woods Hole, MA 02543-1541 ',...
'               USA ', ...
'               FAX: 508-457-2181 ',...
'               Electronic Mail Address:INTERNET > rlimeburner@whoi.edu',...
'         Address - globec: ',...
'               Robert Groman',...
'               Swift House MS# 38',...
'               Woods Hole, MA 02543-1127',...
'               USA ',...
'               Electronic Mail Address:INTERNET > rgroman@whoi.edu',...
'               FAX: (508) 457-2169',...
'         Address - dods: ',...
'               Electronic Mail Address:INTERNET > support@unidata.ucar.edu ');

Comments = [Comments1 Comments2 Comments4];
